[![Build Status](https://travis-ci.com/keon/detox.svg?token=uEnEPs1KNePMw7bdrXQq&branch=master)](https://travis-ci.org/keon/detox)
[![license](https://img.shields.io/github/license/mashape/apistatus.svg)](LICENSE)

<div align="center">
  <img width="35%" src="docs/source/_static/img/detox.png"><br><br>
</div>

## Intro

**Detox** is an open source software library for machine learning security.
It contains tools for adversarial example generation and provides a framework
for building new types of attack methods.

Currently in the dev stage.

## Attacks

Available attack algorithms implemented in Detox:

* Fast Gradient Methods (FGM/FGSM) [`Tutorial`](/tutorial/source/fgsm.ipynb)
* Basic Iterative [`Tutorial`](/tutorial/source/basic_iterative.ipynb)
* Momentum Iterative [`Tutorial`](/tutorial/source/momentum_iterative.ipynb)
* DeepFool
* Universal Adversarial Perturbation (UAP)
* Jacobian-based Saliency Map Approach (JSMA)
* One Pixel Attack
* LBFGS
* Carlini Wagner L2
* Carlini Wagner L-inf
* Feature Adversaries
* Boundary Attack
* Elastic Net
* Natural Adversarial Examples (NAE)


### The Team

Detox is a community driven project.
The project was initiated by machine learning security team @
[KakaoBrain](kakaobrain.com).
